@@ -107,7 +107,11 @@ func addScalars(context Context, target *CandidateNode, lhs *yaml.Node, rhs *yam
 
 	} else if lhsTag == "!!str" {
 		target.Node.Tag = lhs.Tag
-		target.Node.Value = lhs.Value + rhs.Value
+		if rhsTag == "!!null" {
+			target.Node.Value = lhs.Value
+		} else {
+			target.Node.Value = lhs.Value + rhs.Value
+		}
 	} else if rhsTag == "!!str" {
 		target.Node.Tag = rhs.Tag
 		target.Node.Value = lhs.Value + rhs.Value
