@@ -8,28 +8,28 @@ var pickOperatorScenarios = []expressionScenario{
 	{
 		description:    "Pick keys from map",
 		subdescription: "Note that the order of the keys matches the pick order and non existent keys are skipped.",
-		document:       "myMap: {cat: meow, dog: bark, thing: hamster, hamster: squeek}\n",
+		document:       "myMap: {cat: meow, dog: bark, thing: hamster, hamster: squeak}\n",
 		expression:     `.myMap |= pick(["hamster", "cat", "goat"])`,
 		expected: []string{
-			"D0, P[], (doc)::myMap: {hamster: squeek, cat: meow}\n",
+			"D0, P[], (doc)::myMap: {hamster: squeak, cat: meow}\n",
 		},
 	},
 	{
 		description: "Pick keys from map",
 		skipDoc:     true,
-		document:    "!things myMap: {cat: meow, dog: bark, thing: hamster, hamster: squeek}\n",
+		document:    "!things myMap: {cat: meow, dog: bark, thing: hamster, hamster: squeak}\n",
 		expression:  `.myMap |= pick(["hamster", "cat", "goat"])`,
 		expected: []string{
-			"D0, P[], (doc)::!things myMap: {hamster: squeek, cat: meow}\n",
+			"D0, P[], (doc)::!things myMap: {hamster: squeak, cat: meow}\n",
 		},
 	},
 	{
 		description: "Pick keys from map with comments",
 		skipDoc:     true,
-		document:    "# abc\nmyMap: {cat: meow, dog: bark, thing: hamster, hamster: squeek}\n# xyz\n",
+		document:    "# abc\nmyMap: {cat: meow, dog: bark, thing: hamster, hamster: squeak}\n# xyz\n",
 		expression:  `.myMap |= pick(["hamster", "cat", "goat"])`,
 		expected: []string{
-			"D0, P[], (doc)::# abc\nmyMap: {hamster: squeek, cat: meow}\n# xyz\n",
+			"D0, P[], (doc)::# abc\nmyMap: {hamster: squeak, cat: meow}\n# xyz\n",
 		},
 	},
 	{
