@@ -20,6 +20,7 @@ import (
 type expressionScenario struct {
 	description           string
 	subdescription        string
+	explanation           []string
 	environmentVariables  map[string]string
 	document              string
 	document2             string
@@ -256,6 +257,14 @@ func documentOperatorScenario(t *testing.T, w *bufio.Writer, i interface{}) {
 	writeOrPanic(w, "will output\n")
 
 	documentOutput(t, w, s, formattedDoc, formattedDoc2)
+
+	if len(s.explanation) > 0 {
+		writeOrPanic(w, "### Explanation:\n")
+		for _, text := range s.explanation {
+			writeOrPanic(w, fmt.Sprintf("- %v\n", text))
+		}
+		writeOrPanic(w, "\n")
+	}
 }
 
 func documentInput(w *bufio.Writer, s expressionScenario) (string, string) {
